from viur.datastore.types import KEY_SPECIAL_PROPERTY, DATASTORE_BASE_TYPES, SortOrder, SkelListRef, Entity, \
	QueryDefinition, Key, currentDbAccessLog
from viur.datastore.query import Query
from viur.datastore.utils import fixUnindexableProperties, normalizeKey, keyHelper, IsInTransaction, GetOrInsert,\
	encodeKey, acquireTransactionSuccessMarker, startDataAccessLog, endDataAccessLog
from viur.datastore.transport import Get, Put, Delete, RunInTransaction, Collision, AllocateIDs
from viur.datastore.config import conf as config

__all__ = ["KEY_SPECIAL_PROPERTY", "DATASTORE_BASE_TYPES", "SortOrder", "SkelListRef", "Entity", "QueryDefinition",
		   "Key", "Query", "fixUnindexableProperties", "normalizeKey", "keyHelper", "Get", "Put", "Delete",
		   "RunInTransaction", "IsInTransaction", "currentDbAccessLog", "GetOrInsert", "encodeKey",
		   "acquireTransactionSuccessMarker", "Collision", "AllocateIDs", "config", "startDataAccessLog",
		   "endDataAccessLog"]



"""
	This file just holds some configuration variables that will influence
	the behaviour of this library.
"""
conf = {
	# If set, we'll log each query we run
	"traceQueries": False,

	# A reference to the skeleton container of ViUR. Unless set, fetch() and getSkel() will fail
	"SkeletonInstanceRef": None,
}
